@@ -107,8 +107,9 @@ inline bool operator!=(const Ref lhs, const Ref rhs) noexcept
 
 inline bool operator<(const Ref lhs, const Ref rhs) noexcept
 {
-    if (lhs.num != rhs.num)
+    if (lhs.num != rhs.num) {
         return lhs.num < rhs.num;
+    }
     return lhs.gen < rhs.gen;
 }
 
@@ -414,24 +415,11 @@ public:
         OBJECT_TYPE_CHECK(objString);
         return string;
     }
-    // After takeString() the only method that should be called for the object is free().
-    GooString *takeString()
-    {
-        OBJECT_TYPE_CHECK(objString);
-        type = objDead;
-        return string;
-    }
     const GooString *getHexString() const
     {
         OBJECT_TYPE_CHECK(objHexString);
         return string;
     }
-    GooString *takeHexString()
-    {
-        OBJECT_TYPE_CHECK(objHexString);
-        type = objDead;
-        return string;
-    }
     const char *getName() const
     {
         OBJECT_TYPE_CHECK(objName);
